@@ -100,8 +100,8 @@ def process_orderbook_metrics(orderbook_df = None, id=False, amounts_to_pass = [
                 'id':id,
                 'pair':pair,
                 'amount':amount_to_pass,
-                f'sold_max_rate_of_change':sold_max_rate_of_change,
-                f'bid_max_rate_of_change':bought_max_rate_of_change,
+                f'sold_max_rate_of_change':-sold_max_rate_of_change,#### we want to get the lowest slope magnitude
+                f'bid_max_rate_of_change':-bought_max_rate_of_change,#### we want to get the lowest slope magnitude
                 f'buying_slippage' :buying_slippage ,
                 f'selling_slippage' : selling_slippage,
                 f'bid_ask_spread': (best_ask_price-best_bid_price)/best_bid_price,
